@@ -39,12 +39,12 @@ def checkProb(value):
 def checkFileParams(fileParams):
     supportedExtensions = ['txt', 'csv', 'json']
 
-    if 'fileName' not in fileParams:
-        raise Warning("fileParams has to be a dictionary with fileName for the data source\n"
+    if 'filePath' not in fileParams:
+        raise Warning("fileParams has to be a dictionary with filePath for the data source\n"
                       "and txtSeperator key for txt files(default is '\\n') or a column key for csv and json files.")
 
-    fileName = fileParams['fileName']
-    fileExtension = fileName.split(".")[-1]
+    filePath = fileParams['filePath']
+    fileExtension = filePath.split(".")[-1]
 
     if fileExtension in supportedExtensions:
         
@@ -53,9 +53,9 @@ def checkFileParams(fileParams):
 
         elif fileExtension == 'txt':
             txtSeperator = fileParams.get('txtSeperator') or '\n'
-            return fileName, fileExtension, txtSeperator
+            return filePath, fileExtension, txtSeperator
         
-        return fileName, fileExtension, fileParams['column']
+        return filePath, fileExtension, fileParams['column']
 
     raise Warning("Only works with txt, csv, and json files.")
 
@@ -83,11 +83,9 @@ def chooseFromTop(probs, n=5):
     tokensProb, topIx = torch.topk(probs, k=n)
     tokensProb = tokensProb / torch.sum(tokensProb) # Normalize
     tokensProb = tokensProb.cpu().detach().numpy()
-    print(tokensProb)
 
     choice = np.random.choice(n, 1, p = tokensProb)
     tokenId = topIx[choice][0]
-    print(tokenId)
     return int(tokenId)
 
 
