@@ -36,7 +36,6 @@ class GPT2:
 		self.__examples = None
 		self.__seeds = None
 		self.__model = None
-		
 		self.__getModel()
 		self.__tokenizer = self.__getTokenizer()
 		self.__optimizer = self.__getOptimizer()
@@ -157,11 +156,11 @@ class GPT2:
 					else: #topk
 						nextTokenId = chooseFromTop(logits[0,-1], n=k)
 
-					curIds = torch.cat([curIds.long() ,torch.tensor([[nextTokenId]]).long()], dim = 1)
+					curIds = torch.cat([curIds.long() ,torch.tensor([[nextTokenId]]).long().to(self.device)], dim = 1)
 					if nextTokenId in self.__tokenizer.encode(self.__eos):
 						break
 
-				doc = self.__tokenizer.decode(list(curIds.squeeze().to('cpu').numpy())[2:]).strip()
+				doc = self.__tokenizer.decode(list(curIds.squeeze().to('cpu').numpy())[2:-1]).strip()
 				if uniq:
 					if doc not in self.__examples:
 						res.add(doc)
@@ -170,15 +169,12 @@ class GPT2:
 
 		return list(res)
 
-
-if __name__ == "__main__":
-	print("RUN FROM MAIN")
-
+if __name__ == "genn.gpt2":
 	try:
 		from pytorch_transformers import GPT2Tokenizer, GPT2LMHeadModel, AdamW, WarmupLinearSchedule
 	
-	except:
-		print("NOt installed")
-		raise Exception
+	except ModuleNotFoundError:
+		raise Warning("Please install pytorch_transformers module first.\n"
+					  "Using: pip install pytorch_transformers ")
 
 
